@@ -1,46 +1,26 @@
 package Datahub::Factory;
 
-our $VERSION = '0.11';
+our $VERSION = '0.5';
 
 use Datahub::Factory::Sane;
 
 use Datahub::Factory::Env;
 use Datahub::Factory::Config;
-use Datahub::Factory::PipelineConfig;
 use namespace::clean;
 use Sub::Exporter::Util qw(curry_method);
 use Sub::Exporter -setup => {
     exports => [
         log              => curry_method,
         cfg              => curry_method,
-        importer         => curry_method,
-        fixer            => curry_method,
-        store            => curry_method,
-        exporter         => curry_method,
-        pipeline         => curry_method,
-        module           => curry_method,
     ],
-    collectors => {'-load' => \'_import_load', ':load' => \'_import_load'},
+    collectors => {'-load' => \'_import_load', ':load' => \'_import_load',},
 };
 
 sub _import_load {
-    my ($self, $value, $data) = @_;
-
-    if (is_array_ref $value) {
-      self->load(@$value);
-    }
-    else {
-      $self->load;
-    }
-
-    1;
-}
-
-sub load {
-    my $class = shift;
-    my $env   = Datahub::Factory::Env->new();
-    $class->_env($env);
-    $class;
+  my $class = shift;
+  my $env   = Datahub::Factory::Env->new();
+  $class->_env($env);
+  $class;
 }
 
 sub _env {
@@ -51,21 +31,6 @@ sub _env {
         ||= Datahub::Factory::Env->new();
 }
 
-sub importer {
-    my $class = shift;
-    $class->_env->importer(@_);
-}
-
-sub fixer {
-    my $class = shift;
-    $class->_env->fixer(@_);
-}
-
-sub exporter {
-    my $class = shift;
-    $class->_env->exporter(@_);
-}
-
 sub log {
 	$_[0]->_env->log;
 }
@@ -75,16 +40,6 @@ sub cfg {
     return $cfg->config;
 }
 
-sub pipeline {
-    my $class = shift;
-    return $class->_env->pipeline(@_);
-}
-
-sub module {
-    my $class = shift;
-    return $class->_env->module(@_);
-}
-
 1;
 __END__
 
@@ -93,7 +48,7 @@ __END__
 
 =head1 NAME
 
-=for html <a href="https://travis-ci.org/thedatahub/Datahub-Factory"><img src="https://travis-ci.org/thedatahub/Datahub-Factory.svg?branch=master"></a>
+[![Build Status](https://travis-ci.org/thedatahub/Datahub-Factory.svg?branch=master)](https://travis-ci.org/thedatahub/Datahub-Factory)
 
 Datahub::Factory - A conveyor belt which transports data from a data source to
 a data sink.
@@ -128,23 +83,44 @@ functional requirements of the Flemish Art Collection use case.
 
 =head1 CONFIGURATION
 
-=head2 Command line options
+Datahub::Factory uses a general configuration file called I<settings.ini>. It
+can be located at C</etc/datahub-factory/settings.ini> or C<conf/settings.ini>.
+The one in C</etc> takes priority. An example file is provided at
+L<conf/settings.example.ini|https://github.com/thedatahub/Datahub-Factory/blob/master/conf/settings.example.ini>. It is in L<INI format|http://search.cpan.org/~sherzodr/Config-Simple-4.59/Simple.pm#INI-FILE>.
 
-All commands share the following switches:
+It has two parts, a C<[General]> block that contains some generic options, and
+(optionally) multiple module-specific blocks called C<[module_Module_name]>.
+For a list of module options, see the documentation for every module.
+
+Supported modules
 
 =over
 
-=item C<--log_level>
+=item L<PIDS|Datahub::Factory::Importer::PIDS>
+
+=back
+
+=head2 General options
+
+=over
+
+=item C<log_level>
 
 Set the log_level. Takes a numeric parameter. Supported levels are:
 1 (WARN), 2 (INFO), 3 (DEBUG). WARN (1) is the default.
 
-=item C<--log_output>
-
-Selects an output for the log messages. By default, it will send them to STDERR (pass C<STDERR> as parameter), but STDOUT (C<STDOUT>) and a log file (C<logs/import_-date-.log>) (C<STATISTICS>) are also supported.
-
 =back
 
+=head2 Example
+
+    [General]
+    # 1 => WARN; 2 => INFO; 3 => DEBUG
+    log_level = 1
+
+    [module_PIDS]
+    username = username
+    api_key = api_key
+
 =head1 COMMANDS
 
 =head2 help COMMAND
@@ -162,6 +138,13 @@ export the data.
 
 L<Datahub::Factory::Command::transport>
 
+=head2 merge [OPTIONS] (experimental)
+
+Fetch data from two sources, convert it to an exchange format, merge the
+two records and export the data.
+
+L<Datahub::Factory::Command::merge>
+
 =head1 AUTHORS
 
 =over
