@@ -1,16 +1,17 @@
 package Datahub::Factory::Importer::Adlib;
 
-use Datahub::Factory::Sane;
+use strict;
+use warnings;
 
 use Moo;
 use Catmandu;
-use namespace::clean;
 
 with 'Datahub::Factory::Importer';
 
 has file_name => (is => 'ro', required => 1);
 has data_path => (is => 'ro', default => sub { return 'recordList.record.*'; });
 
+
 sub _build_importer {
     my $self = shift;
     my $importer = Catmandu->importer('XML', file => $self->file_name, data_path => $self->data_path);
@@ -18,7 +19,6 @@ sub _build_importer {
 }
 
 1;
-
 __END__
 
 =encoding utf-8
@@ -90,4 +90,4 @@ it under the same terms as Perl itself.
 L<Datahub::Factory>
 L<Catmandu>
 
-=cut
+=cut
\ No newline at end of file
